@@ -663,9 +663,9 @@ def get_pyopencl_fixture_arg_names(metafunc, extra_arg_names=None):
 
         if arg == "ctx_getter":
             from warnings import warn
-            warn("The 'ctx_getter' arg is deprecated in "
-                    "favor of 'ctx_factory'.",
-                    DeprecationWarning)
+            warn(
+                "The 'ctx_getter' arg is deprecated in favor of 'ctx_factory'.",
+                DeprecationWarning, stacklevel=2)
 
         arg_names.append(arg)
 
@@ -757,7 +757,7 @@ class DtypedArgument(Argument):
                 self.dtype)
 
     def __eq__(self, other: Any) -> bool:
-        return (type(self) == type(other)
+        return (type(self) is type(other)
                 and self.dtype == other.dtype
                 and self.name == other.name)
 
@@ -812,7 +812,7 @@ class OtherArg(Argument):
         return self.decl
 
     def __eq__(self, other) -> bool:
-        return (type(self) == type(other)
+        return (type(self) is type(other)
                 and self.decl == other.decl
                 and self.name == other.name)
 
@@ -903,9 +903,9 @@ def get_arg_offset_adjuster_code(arg_types):
             result.append("__global %(type)s *%(name)s = "
                     "(__global %(type)s *) "
                     "((__global char *) %(name)s__base + %(name)s__offset);"
-                    % dict(
-                        type=dtype_to_ctype(arg_type.dtype),
-                        name=arg_type.name))
+                    % {
+                        "type": dtype_to_ctype(arg_type.dtype),
+                        "name": arg_type.name})
 
     return "\n".join(result)
 
@@ -1097,26 +1097,22 @@ def match_dtype_to_c_struct(device, name, dtype, context=None):
             "result[%d] = pycl_offsetof(%s, %s);" % (i+1, name, field_name)
             for i, (field_name, _) in enumerate(fields))
 
-    src = r"""
+    src = rf"""
         #define pycl_offsetof(st, m) \
                  ((uint) ((__local char *) &(dummy.m) \
                  - (__local char *)&dummy ))
 
-        %(pre_decls)s
+        {pre_decls}
 
-        %(my_decl)s
+        {c_decl}
 
         __kernel void get_size_and_offsets(__global uint *result)
-        {
-            result[0] = sizeof(%(my_type)s);
-            __local %(my_type)s dummy;
-            %(offset_code)s
-        }
-    """ % dict(
-            pre_decls=pre_decls,
-            my_decl=c_decl,
-            my_type=name,
-            offset_code=offset_code)
+        {{
+            result[0] = sizeof({name});
+            __local {name} dummy;
+            {offset_code}
+        }}
+    """
 
     if context is None:
         context = cl.Context([device])
