@@ -69,8 +69,8 @@ def test_clrandom_dtypes(ctx_factory, rng_class, dtype):
         if device.platform.vendor == "The pocl project" \
                 and device.type & cl.device_type.GPU \
                 and rng_class is make_ranlux_generator:
-            pytest.xfail("ranlux test fails on POCL + Nvidia,"
-                    "at least the K40, as of pocl 1.6, 2021-01-20")
+            pytest.xfail("ranlux test fails on PoCL + Nvidia,"
+                    "at least the K40, as of PoCL 1.6, 2021-01-20")
 
         rng.uniform(queue, size, dtype)
 
